==> fractal_repositories-1.1.1.tar.gz: fractal_repositories-1.1.1/tests/fixtures/firestore.py <==
from abc import ABC
from dataclasses import dataclass
from datetime import date, datetime

import pytest


@pytest.fixture
def firestore_test_model(now):
    from fractal_repositories.core.entity import Entity

    @dataclass
    class TestModelFirestore(Entity):
        id: str
        name: str = "test"
        description: str = "test"
        created_on: date = now
        created_at: datetime = now

    return TestModelFirestore


@pytest.fixture
def firebase_client_mock(mocker):
    from mockfirestore import CollectionReference, MockFirestore  # type: ignore

    def count(self):
        class Result:
            def __init__(self, value):
                self.value = value

        class Query:
            def get(_):
                return [[Result(len(list(self.stream())))]]

        return Query()

    CollectionReference.count = count

    mocker.patch("firebase_admin.firestore.client", lambda: MockFirestore())


@pytest.fixture
def firestore_test_repository(firestore_test_model, firebase_client_mock):
    from fractal_repositories.contrib.gcp.firestore.mixins import (
        FirestoreRepositoryMixin,
    )
    from fractal_repositories.core.repositories import Repository

    class TestRepository(Repository[firestore_test_model], ABC):
        entity = firestore_test_model

    class FirestoreTestRepository(
        TestRepository, FirestoreRepositoryMixin[firestore_test_model]
    ): ...

    repository = FirestoreTestRepository(collection="test")

    yield repository

    repository.collection._data.clear()

==> fractal_repositories-1.2.2.tar.gz: fractal_repositories-1.2.2/tests/fixtures/firestore.py <==
from abc import ABC
from dataclasses import dataclass
from datetime import date, datetime

import pytest


@pytest.fixture
def firestore_test_model(now):
    from fractal_repositories.core.entity import Entity

    @dataclass
    class TestModelFirestore(Entity):
        id: str
        name: str = "test"
        description: str = "test"
        created_on: date = now
        created_at: datetime = now

    return TestModelFirestore


@pytest.fixture
def firebase_client_mock(mocker):
    from mockfirestore import CollectionReference, MockFirestore, Query  # type: ignore

    def count(self):
        class Result:
            def __init__(self, value):
                self.value = value

        class Query:
            def get(_):
                return [[Result(len(list(self.stream())))]]

        return Query()

    CollectionReference.count = count
    Query.count = count

    mocker.patch("firebase_admin.firestore.client", lambda: MockFirestore())


@pytest.fixture
def firestore_test_repository(firestore_test_model, firebase_client_mock):
    from fractal_repositories.contrib.gcp.firestore.mixins import (
        FirestoreRepositoryMixin,
    )
    from fractal_repositories.core.repositories import Repository

    class TestRepository(Repository[firestore_test_model], ABC):
        entity = firestore_test_model

    class FirestoreTestRepository(
        TestRepository, FirestoreRepositoryMixin[firestore_test_model]
    ): ...

    repository = FirestoreTestRepository(collection="test")

    yield repository

    repository.collection._data.clear()
